/* Generated by Nim Compiler v2.2.10 */
#define NIM_INTBITS 64

#include "nimbase.h"
#include <string.h>
#undef LANGUAGE_C
#undef MIPSEB
#undef MIPSEL
#undef PPC
#undef R3000
#undef R4000
#undef i386
#undef linux
#undef mips
#undef near
#undef far
#undef powerpc
#undef unix
typedef struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw;
typedef struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA tySequence__E0kio2ZnplNTuln9bsnljSA;
typedef struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content tySequence__E0kio2ZnplNTuln9bsnljSA_Content;
typedef struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw tySequence__7lEisrXlQEzwtUKW5pzRCw;
typedef struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content tySequence__7lEisrXlQEzwtUKW5pzRCw_Content;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA tySequence__hTEiKNj3evQAjIXUI21elA;
typedef struct tySequence__hTEiKNj3evQAjIXUI21elA_Content tySequence__hTEiKNj3evQAjIXUI21elA_Content;
typedef struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ;
typedef struct NimStrPayload NimStrPayload;
typedef struct NimStringV2 NimStringV2;
typedef struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ tySequence__sM4lkSb7zS6F7OVMvW9cffQ;
typedef struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content;
typedef struct tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA;
typedef struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA;
typedef struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg;
typedef struct Exception Exception;
typedef struct RootObj RootObj;
typedef struct TNimTypeV2 TNimTypeV2;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ tySequence__S89cE01OvNjsN9c71FKsSrqQ;
typedef struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content;
typedef struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A;
typedef struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w;
typedef struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg;
typedef struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q tyTuple__N4J9cV4JZGem3ljqqj5rT0Q;
typedef struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg;
typedef struct tyTuple__DTRsWi2kgTewbhN2TT5mbA tyTuple__DTRsWi2kgTewbhN2TT5mbA;
typedef struct tyTuple__47w2DboNEPf69aPgubZdd7Q tyTuple__47w2DboNEPf69aPgubZdd7Q;
typedef struct tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA;
typedef struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw tyTuple__xYhUhS7X82rKTqbT9bRfCnw;
typedef struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA;
struct tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA {
	NU16 line;
	NI16 col;
	NI32 fileIndex;
};
typedef NU8 tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw;
struct tySequence__E0kio2ZnplNTuln9bsnljSA {
  NI len; tySequence__E0kio2ZnplNTuln9bsnljSA_Content* p;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw {
  NI len; tySequence__7lEisrXlQEzwtUKW5pzRCw_Content* p;
};
struct tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A {
	tySequence__7lEisrXlQEzwtUKW5pzRCw data;
	NI counter;
};
struct tySequence__hTEiKNj3evQAjIXUI21elA {
  NI len; tySequence__hTEiKNj3evQAjIXUI21elA_Content* p;
};
struct tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA trackPos;
	NIM_BOOL trackPosAttached;
	tySet_tyEnum_TErrorOutput__wGgqZXVnY1wkKEe8EL9cL9aw errorOutputs;
	tySequence__E0kio2ZnplNTuln9bsnljSA msgContext;
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA lastError;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A filenameToIndexTbl;
	tySequence__hTEiKNj3evQAjIXUI21elA fileInfos;
	NI32 systemFileIdx;
};
struct NimStrPayload {
	NI cap;
	NIM_CHAR data[SEQ_DECL_SIZE];
};
struct NimStringV2 {
	NI len;
	NimStrPayload* p;
};
struct tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA Field0;
	NimStringV2 Field1;
};
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ {
  NI len; tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content* p;
};
struct tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw {
	NimStringV2 fullPath;
	NimStringV2 projPath;
	NimStringV2 shortName;
	NimStringV2 quotedName;
	NimStringV2 quotedFullName;
	tySequence__sM4lkSb7zS6F7OVMvW9cffQ lines;
	NimStringV2 dirtyFile;
	NimStringV2 hash;
	NIM_BOOL dirty;
};
typedef NU8 tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw[13];
typedef tySet_tyEnum_TMsgKind__4CaO62Zp2vRXWqMPzLEOAw tyArray__jQ6Zibb0SzsKfL1Qwwi9bag[4];
typedef NU8 tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA;
typedef NimStringV2 tyArray__pKMShAYxu8WJVt39cC69bQ9aQ[124];
struct TNimTypeV2 {
	void* destructor;
	NI size;
	NI16 align;
	NI16 depth;
	NU32* display;
	void* traceImpl;
	void* typeInfoV1;
	NI flags;
	void* vTable[SEQ_DECL_SIZE];
};
struct RootObj {
	TNimTypeV2* m_type;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ {
  NI len; tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content* p;
};
struct Exception {
	RootObj Sup;
	Exception* parent;
	NCSTRING name;
	NimStringV2 message;
	tySequence__S89cE01OvNjsN9c71FKsSrqQ trace;
	Exception* up;
};
struct tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg {
	Exception Sup;
};
struct tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA {
	tyObject_CatchableError__TCF9b1Y9b2ct0xPZvZnaY7gg Sup;
};
struct tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA {
	tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA Sup;
};
struct tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A {
	NI rc;
	NI rootIdx;
};
struct tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg {
	NI len;
	NI cap;
	tyTuple__N4J9cV4JZGem3ljqqj5rT0Q* d;
};
struct tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg {
	NI len;
	NI cap;
	tyTuple__DTRsWi2kgTewbhN2TT5mbA* d;
};
struct tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w {
	tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg traceStack;
	tyObject_CellSeq__IHvIqxITv1yMjJj8lwLrhg toFree;
	NI freed;
	NI touched;
	NI edges;
	NI rcSum;
	NIM_BOOL keepThreshold;
};
struct tyTuple__N4J9cV4JZGem3ljqqj5rT0Q {
	void** Field0;
	TNimTypeV2* Field1;
};
struct tyTuple__47w2DboNEPf69aPgubZdd7Q {
	NI Field0;
	NI Field1;
	NI Field2;
};
struct tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA {
	tyObject_ValueError__S29bKZF4TUS33IR7ZXb7fFA Sup;
};
struct tySequence__E0kio2ZnplNTuln9bsnljSA_Content { NI cap; tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ data[SEQ_DECL_SIZE]; };
struct tyTuple__xYhUhS7X82rKTqbT9bRfCnw {
	NI Field0;
	NimStringV2 Field1;
	NI32 Field2;
};
struct tySequence__7lEisrXlQEzwtUKW5pzRCw_Content { NI cap; tyTuple__xYhUhS7X82rKTqbT9bRfCnw data[SEQ_DECL_SIZE]; };
struct tySequence__hTEiKNj3evQAjIXUI21elA_Content { NI cap; tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw data[SEQ_DECL_SIZE]; };
struct tySequence__sM4lkSb7zS6F7OVMvW9cffQ_Content { NI cap; NimStringV2 data[SEQ_DECL_SIZE]; };
struct tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA {
	NCSTRING procname;
	NI line;
	NCSTRING filename;
};
struct tySequence__S89cE01OvNjsN9c71FKsSrqQ_Content { NI cap; tyObject_StackTraceEntry__RcJz5RXFIYjIseutvVFICA data[SEQ_DECL_SIZE]; };
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1);
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void*, newSeqPayload)(NI cap_p0, NI elemSize_p1, NI elemAlign_p2);
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, eqdup___lineinfos_u2037)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA src_p0);
N_LIB_PRIVATE N_NIMCALL(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A, initTable__lineinfos_u410)(NI initialSize_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u548)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, X5BX5Deq___lineinfos_u646)(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A* t_p0, NimStringV2 key_p1, NI32 val_p2);
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void);
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___system_u2694)(NimStringV2* dest_p0, NimStringV2 src_p1);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u2691)(NimStringV2 dest_p0);
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1);
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2);
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2);
N_LIB_PRIVATE N_NIMCALL(void, prepareAdd)(NimStringV2* s_p0, NI addLen_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, rawNewString)(NI space_p0);
N_LIB_PRIVATE N_NIMCALL(void*, nimNewObj)(NI size_p0, NI alignment_p1);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__lineinfos_u2356)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u305)(tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA* dest_p0);
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0);
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NOINLINE(void, rememberCycle__system_u3497)(NIM_BOOL isDestroyAction_p0, tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* s_p1, TNimTypeV2* desc_p2);
N_LIB_PRIVATE N_NIMCALL(void, nimDestroyAndDispose)(void* p_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___system_u3699)(tySequence__S89cE01OvNjsN9c71FKsSrqQ dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___lineinfos_u317)(tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA* dest_p0, void* env_p1);
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1);
static N_INLINE(void, add__system_u3018)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2);
N_LIB_PRIVATE N_NIMCALL(void, resize__system_u3026)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0);
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1);
N_LIB_PRIVATE N_NIMCALL(NimStringV2, eqdup___system_u2697)(NimStringV2 src_p0);
N_LIB_PRIVATE N_NIMCALL(void, raiseExceptionEx)(Exception* e_p0, NCSTRING ename_p1, NCSTRING procname_p2, NCSTRING filename_p3, NI line_p4);
N_LIB_PRIVATE N_NIMCALL(NI, hash__lineinfos_u264)(tyTuple__47w2DboNEPf69aPgubZdd7Q x_p0);
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__lineinfos_u2358)(void* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___msgs_u488)(tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA* dest_p0);
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___msgs_u500)(tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA* dest_p0, void* env_p1);
static const struct {
  NI cap; NIM_CHAR data[3+1];
} TM__fug3IAAsDRtODxWPJjHlFg_2 = { 3 | NIM_STRLIT_FLAG, "\?\?\?" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_3 = {3, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_2};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_4 = { 10 | NIM_STRLIT_FLAG, "errUnknown" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_5 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_4};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__fug3IAAsDRtODxWPJjHlFg_6 = { 8 | NIM_STRLIT_FLAG, "errFatal" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_7 = {8, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_6};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_8 = { 11 | NIM_STRLIT_FLAG, "errInternal" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_9 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_8};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_10 = { 16 | NIM_STRLIT_FLAG, "errIllFormedAstX" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_11 = {16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_10};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__fug3IAAsDRtODxWPJjHlFg_12 = { 17 | NIM_STRLIT_FLAG, "errCannotOpenFile" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_13 = {17, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_12};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_14 = { 12 | NIM_STRLIT_FLAG, "errXExpected" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_15 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_14};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__fug3IAAsDRtODxWPJjHlFg_16 = { 20 | NIM_STRLIT_FLAG, "errRstMissingClosing" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_17 = {20, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_16};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__fug3IAAsDRtODxWPJjHlFg_18 = { 29 | NIM_STRLIT_FLAG, "errRstGridTableNotImplemented" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_19 = {29, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_18};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__fug3IAAsDRtODxWPJjHlFg_20 = { 28 | NIM_STRLIT_FLAG, "errRstMarkdownIllformedTable" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_21 = {28, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_20};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__fug3IAAsDRtODxWPJjHlFg_22 = { 20 | NIM_STRLIT_FLAG, "errRstIllformedTable" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_23 = {20, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_22};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__fug3IAAsDRtODxWPJjHlFg_24 = { 24 | NIM_STRLIT_FLAG, "errRstNewSectionExpected" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_25 = {24, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_24};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__fug3IAAsDRtODxWPJjHlFg_26 = { 23 | NIM_STRLIT_FLAG, "errRstGeneralParseError" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_27 = {23, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_26};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__fug3IAAsDRtODxWPJjHlFg_28 = { 23 | NIM_STRLIT_FLAG, "errRstInvalidDirectiveX" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_29 = {23, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_28};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__fug3IAAsDRtODxWPJjHlFg_30 = { 18 | NIM_STRLIT_FLAG, "errRstInvalidField" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_31 = {18, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_30};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__fug3IAAsDRtODxWPJjHlFg_32 = { 22 | NIM_STRLIT_FLAG, "errRstFootnoteMismatch" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_33 = {22, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_32};
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__fug3IAAsDRtODxWPJjHlFg_34 = { 24 | NIM_STRLIT_FLAG, "errRstSandboxedDirective" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_35 = {24, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_34};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_36 = { 12 | NIM_STRLIT_FLAG, "errProveInit" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_37 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_36};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_38 = { 12 | NIM_STRLIT_FLAG, "errGenerated" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_39 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_38};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_40 = { 13 | NIM_STRLIT_FLAG, "errFailedMove" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_41 = {13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_40};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__fug3IAAsDRtODxWPJjHlFg_42 = { 7 | NIM_STRLIT_FLAG, "errUser" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_43 = {7, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_42};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__fug3IAAsDRtODxWPJjHlFg_44 = { 14 | NIM_STRLIT_FLAG, "CannotOpenFile" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_45 = {14, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_44};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_46 = { 11 | NIM_STRLIT_FLAG, "OctalEscape" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_47 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_46};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_48 = { 12 | NIM_STRLIT_FLAG, "XIsNeverRead" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_49 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_48};
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__fug3IAAsDRtODxWPJjHlFg_50 = { 17 | NIM_STRLIT_FLAG, "XmightNotBeenInit" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_51 = {17, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_50};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_52 = { 10 | NIM_STRLIT_FLAG, "Deprecated" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_53 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_52};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_54 = { 16 | NIM_STRLIT_FLAG, "ConfigDeprecated" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_55 = {16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_54};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_56 = { 10 | NIM_STRLIT_FLAG, "DotLikeOps" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_57 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_56};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__fug3IAAsDRtODxWPJjHlFg_58 = { 21 | NIM_STRLIT_FLAG, "SmallLshouldNotBeUsed" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_59 = {21, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_58};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_60 = { 12 | NIM_STRLIT_FLAG, "UnknownMagic" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_61 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_60};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__fug3IAAsDRtODxWPJjHlFg_62 = { 19 | NIM_STRLIT_FLAG, "RedefinitionOfLabel" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_63 = {19, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_62};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__fug3IAAsDRtODxWPJjHlFg_64 = { 20 | NIM_STRLIT_FLAG, "UnknownSubstitutionX" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_65 = {20, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_64};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_66 = { 13 | NIM_STRLIT_FLAG, "AmbiguousLink" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_67 = {13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_66};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_68 = { 10 | NIM_STRLIT_FLAG, "BrokenLink" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_69 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_68};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__fug3IAAsDRtODxWPJjHlFg_70 = { 21 | NIM_STRLIT_FLAG, "LanguageXNotSupported" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_71 = {21, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_70};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__fug3IAAsDRtODxWPJjHlFg_72 = { 18 | NIM_STRLIT_FLAG, "FieldXNotSupported" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_73 = {18, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_72};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__fug3IAAsDRtODxWPJjHlFg_74 = { 15 | NIM_STRLIT_FLAG, "UnusedImportdoc" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_75 = {15, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_74};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_76 = { 12 | NIM_STRLIT_FLAG, "warnRstStyle" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_77 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_76};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__fug3IAAsDRtODxWPJjHlFg_78 = { 15 | NIM_STRLIT_FLAG, "CommentXIgnored" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_79 = {15, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_78};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_80 = { 13 | NIM_STRLIT_FLAG, "TypelessParam" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_81 = {13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_80};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__fug3IAAsDRtODxWPJjHlFg_82 = { 7 | NIM_STRLIT_FLAG, "UseBase" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_83 = {7, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_82};
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__fug3IAAsDRtODxWPJjHlFg_84 = { 18 | NIM_STRLIT_FLAG, "WriteToForeignHeap" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_85 = {18, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_84};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_86 = { 10 | NIM_STRLIT_FLAG, "UnsafeCode" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_87 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_86};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_88 = { 12 | NIM_STRLIT_FLAG, "UnusedImport" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_89 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_88};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__fug3IAAsDRtODxWPJjHlFg_90 = { 20 | NIM_STRLIT_FLAG, "InheritFromException" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_91 = {20, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_90};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_92 = { 16 | NIM_STRLIT_FLAG, "EachIdentIsTuple" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_93 = {16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_92};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_94 = { 12 | NIM_STRLIT_FLAG, "UnsafeSetLen" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_95 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_94};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_96 = { 13 | NIM_STRLIT_FLAG, "UnsafeDefault" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_97 = {13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_96};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_98 = { 9 | NIM_STRLIT_FLAG, "ProveInit" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_99 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_98};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_100 = { 10 | NIM_STRLIT_FLAG, "ProveField" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_101 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_100};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_102 = { 10 | NIM_STRLIT_FLAG, "ProveIndex" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_103 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_102};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__fug3IAAsDRtODxWPJjHlFg_104 = { 15 | NIM_STRLIT_FLAG, "UnreachableElse" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_105 = {15, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_104};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__fug3IAAsDRtODxWPJjHlFg_106 = { 15 | NIM_STRLIT_FLAG, "UnreachableCode" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_107 = {15, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_106};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_108 = { 10 | NIM_STRLIT_FLAG, "IndexCheck" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_109 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_108};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__fug3IAAsDRtODxWPJjHlFg_110 = { 8 | NIM_STRLIT_FLAG, "GcUnsafe" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_111 = {8, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_110};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_112 = { 9 | NIM_STRLIT_FLAG, "GcUnsafe2" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_113 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_112};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__fug3IAAsDRtODxWPJjHlFg_114 = { 6 | NIM_STRLIT_FLAG, "Uninit" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_115 = {6, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_114};
static const struct {
  NI cap; NIM_CHAR data[5+1];
} TM__fug3IAAsDRtODxWPJjHlFg_116 = { 5 | NIM_STRLIT_FLAG, "GcMem" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_117 = {5, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_116};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_118 = { 10 | NIM_STRLIT_FLAG, "Destructor" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_119 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_118};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_120 = { 9 | NIM_STRLIT_FLAG, "LockLevel" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_121 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_120};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__fug3IAAsDRtODxWPJjHlFg_122 = { 14 | NIM_STRLIT_FLAG, "ResultShadowed" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_123 = {14, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_122};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__fug3IAAsDRtODxWPJjHlFg_124 = { 7 | NIM_STRLIT_FLAG, "Spacing" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_125 = {7, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_124};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__fug3IAAsDRtODxWPJjHlFg_126 = { 14 | NIM_STRLIT_FLAG, "CaseTransition" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_127 = {14, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_126};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_128 = { 12 | NIM_STRLIT_FLAG, "CycleCreated" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_129 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_128};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_130 = { 16 | NIM_STRLIT_FLAG, "ObservableStores" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_131 = {16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_130};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_132 = { 12 | NIM_STRLIT_FLAG, "StrictNotNil" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_133 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_132};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_134 = { 10 | NIM_STRLIT_FLAG, "ResultUsed" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_135 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_134};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_136 = { 10 | NIM_STRLIT_FLAG, "CannotOpen" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_137 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_136};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_138 = { 11 | NIM_STRLIT_FLAG, "FileChanged" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_139 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_138};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__fug3IAAsDRtODxWPJjHlFg_140 = { 8 | NIM_STRLIT_FLAG, "EnumConv" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_141 = {8, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_140};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_142 = { 11 | NIM_STRLIT_FLAG, "AnyEnumConv" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_143 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_142};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_144 = { 12 | NIM_STRLIT_FLAG, "HoleEnumConv" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_145 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_144};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_146 = { 11 | NIM_STRLIT_FLAG, "CStringConv" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_147 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_146};
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_148 = { 16 | NIM_STRLIT_FLAG, "PtrToCstringConv" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_149 = {16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_148};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__fug3IAAsDRtODxWPJjHlFg_150 = { 6 | NIM_STRLIT_FLAG, "Effect" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_151 = {6, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_150};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_152 = { 9 | NIM_STRLIT_FLAG, "CastSizes" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_153 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_152};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__fug3IAAsDRtODxWPJjHlFg_154 = { 15 | NIM_STRLIT_FLAG, "AboveMaxSizeSet" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_155 = {15, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_154};
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__fug3IAAsDRtODxWPJjHlFg_156 = { 28 | NIM_STRLIT_FLAG, "ImplicitTemplateRedefinition" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_157 = {28, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_156};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_158 = { 12 | NIM_STRLIT_FLAG, "UnnamedBreak" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_159 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_158};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__fug3IAAsDRtODxWPJjHlFg_160 = { 14 | NIM_STRLIT_FLAG, "StmtListLambda" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_161 = {14, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_160};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_162 = { 10 | NIM_STRLIT_FLAG, "BareExcept" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_163 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_162};
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__fug3IAAsDRtODxWPJjHlFg_164 = { 20 | NIM_STRLIT_FLAG, "ImplicitDefaultValue" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_165 = {20, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_164};
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__fug3IAAsDRtODxWPJjHlFg_166 = { 22 | NIM_STRLIT_FLAG, "IgnoredSymbolInjection" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_167 = {22, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_166};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_168 = { 9 | NIM_STRLIT_FLAG, "StdPrefix" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_169 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_168};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_170 = { 12 | NIM_STRLIT_FLAG, "UnknownNotes" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_171 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_170};
static const struct {
  NI cap; NIM_CHAR data[12+1];
} TM__fug3IAAsDRtODxWPJjHlFg_172 = { 12 | NIM_STRLIT_FLAG, "LongLiterals" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_173 = {12, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_172};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__fug3IAAsDRtODxWPJjHlFg_174 = { 4 | NIM_STRLIT_FLAG, "User" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_175 = {4, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_174};
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__fug3IAAsDRtODxWPJjHlFg_176 = { 29 | NIM_STRLIT_FLAG, "GlobalVarConstructorTemporary" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_177 = {29, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_176};
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__fug3IAAsDRtODxWPJjHlFg_178 = { 23 | NIM_STRLIT_FLAG, "ImplicitRangeConversion" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_179 = {23, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_178};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__fug3IAAsDRtODxWPJjHlFg_180 = { 21 | NIM_STRLIT_FLAG, "SystemRangeConversion" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_181 = {21, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_180};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__fug3IAAsDRtODxWPJjHlFg_182 = { 7 | NIM_STRLIT_FLAG, "Success" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_183 = {7, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_182};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__fug3IAAsDRtODxWPJjHlFg_184 = { 8 | NIM_STRLIT_FLAG, "SuccessX" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_185 = {8, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_184};
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__fug3IAAsDRtODxWPJjHlFg_186 = { 2 | NIM_STRLIT_FLAG, "CC" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_187 = {2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_186};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__fug3IAAsDRtODxWPJjHlFg_188 = { 19 | NIM_STRLIT_FLAG, "XDeclaredButNotUsed" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_189 = {19, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_188};
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__fug3IAAsDRtODxWPJjHlFg_190 = { 21 | NIM_STRLIT_FLAG, "DuplicateModuleImport" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_191 = {21, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_190};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_192 = { 13 | NIM_STRLIT_FLAG, "XCannotRaiseY" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_193 = {13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_192};
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__fug3IAAsDRtODxWPJjHlFg_194 = { 19 | NIM_STRLIT_FLAG, "ConvToBaseNotNeeded" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_195 = {19, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_194};
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__fug3IAAsDRtODxWPJjHlFg_196 = { 26 | NIM_STRLIT_FLAG, "ConvFromXtoItselfNotNeeded" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_197 = {26, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_196};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_198 = { 11 | NIM_STRLIT_FLAG, "ExprAlwaysX" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_199 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_198};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_200 = { 10 | NIM_STRLIT_FLAG, "QuitCalled" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_201 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_200};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_202 = { 10 | NIM_STRLIT_FLAG, "Processing" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_203 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_202};
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__fug3IAAsDRtODxWPJjHlFg_204 = { 14 | NIM_STRLIT_FLAG, "ProcessingStmt" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_205 = {14, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_204};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_206 = { 9 | NIM_STRLIT_FLAG, "CodeBegin" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_207 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_206};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__fug3IAAsDRtODxWPJjHlFg_208 = { 7 | NIM_STRLIT_FLAG, "CodeEnd" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_209 = {7, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_208};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__fug3IAAsDRtODxWPJjHlFg_210 = { 4 | NIM_STRLIT_FLAG, "Conf" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_211 = {4, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_210};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__fug3IAAsDRtODxWPJjHlFg_212 = { 4 | NIM_STRLIT_FLAG, "Path" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_213 = {4, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_212};
static const struct {
  NI cap; NIM_CHAR data[8+1];
} TM__fug3IAAsDRtODxWPJjHlFg_214 = { 8 | NIM_STRLIT_FLAG, "CondTrue" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_215 = {8, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_214};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_216 = { 9 | NIM_STRLIT_FLAG, "CondFalse" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_217 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_216};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__fug3IAAsDRtODxWPJjHlFg_218 = { 4 | NIM_STRLIT_FLAG, "Name" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_219 = {4, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_218};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__fug3IAAsDRtODxWPJjHlFg_220 = { 7 | NIM_STRLIT_FLAG, "Pattern" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_221 = {7, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_220};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__fug3IAAsDRtODxWPJjHlFg_222 = { 4 | NIM_STRLIT_FLAG, "Exec" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_223 = {4, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_222};
static const struct {
  NI cap; NIM_CHAR data[4+1];
} TM__fug3IAAsDRtODxWPJjHlFg_224 = { 4 | NIM_STRLIT_FLAG, "Link" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_225 = {4, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_224};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_226 = { 10 | NIM_STRLIT_FLAG, "Dependency" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_227 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_226};
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__fug3IAAsDRtODxWPJjHlFg_228 = { 6 | NIM_STRLIT_FLAG, "Source" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_229 = {6, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_228};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_230 = { 11 | NIM_STRLIT_FLAG, "Performance" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_231 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_230};
static const struct {
  NI cap; NIM_CHAR data[10+1];
} TM__fug3IAAsDRtODxWPJjHlFg_232 = { 10 | NIM_STRLIT_FLAG, "StackTrace" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_233 = {10, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_232};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__fug3IAAsDRtODxWPJjHlFg_234 = { 7 | NIM_STRLIT_FLAG, "GCStats" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_235 = {7, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_234};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_236 = { 9 | NIM_STRLIT_FLAG, "GlobalVar" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_237 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_236};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_238 = { 11 | NIM_STRLIT_FLAG, "ExpandMacro" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_239 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_238};
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_240 = {4, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_174};
static const struct {
  NI cap; NIM_CHAR data[7+1];
} TM__fug3IAAsDRtODxWPJjHlFg_241 = { 7 | NIM_STRLIT_FLAG, "UserRaw" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_242 = {7, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_241};
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__fug3IAAsDRtODxWPJjHlFg_243 = { 15 | NIM_STRLIT_FLAG, "ExtendedContext" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_244 = {15, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_243};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_245 = { 13 | NIM_STRLIT_FLAG, "UnknownRaises" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_246 = {13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_245};
static const struct {
  NI cap; NIM_CHAR data[9+1];
} TM__fug3IAAsDRtODxWPJjHlFg_247 = { 9 | NIM_STRLIT_FLAG, "MsgOrigin" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_248 = {9, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_247};
static const struct {
  NI cap; NIM_CHAR data[11+1];
} TM__fug3IAAsDRtODxWPJjHlFg_249 = { 11 | NIM_STRLIT_FLAG, "DeclaredLoc" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_250 = {11, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_249};
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__fug3IAAsDRtODxWPJjHlFg_251 = { 0 | NIM_STRLIT_FLAG, "" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_252 = {0, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_251};
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_253 = { 13 | NIM_STRLIT_FLAG, "unknown error" };
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__fug3IAAsDRtODxWPJjHlFg_254 = { 15 | NIM_STRLIT_FLAG, "fatal error: $1" };
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__fug3IAAsDRtODxWPJjHlFg_255 = { 18 | NIM_STRLIT_FLAG, "internal error: $1" };
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__fug3IAAsDRtODxWPJjHlFg_256 = { 17 | NIM_STRLIT_FLAG, "illformed AST: $1" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_257 = { 16 | NIM_STRLIT_FLAG, "cannot open \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_258 = { 13 | NIM_STRLIT_FLAG, "\'$1\' expected" };
static const struct {
  NI cap; NIM_CHAR data[2+1];
} TM__fug3IAAsDRtODxWPJjHlFg_259 = { 2 | NIM_STRLIT_FLAG, "$1" };
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__fug3IAAsDRtODxWPJjHlFg_260 = { 29 | NIM_STRLIT_FLAG, "grid table is not implemented" };
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__fug3IAAsDRtODxWPJjHlFg_261 = { 43 | NIM_STRLIT_FLAG, "illformed delimiter row of a markdown table" };
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__fug3IAAsDRtODxWPJjHlFg_262 = { 19 | NIM_STRLIT_FLAG, "Illformed table: $1" };
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__fug3IAAsDRtODxWPJjHlFg_263 = { 23 | NIM_STRLIT_FLAG, "new section expected $1" };
static const struct {
  NI cap; NIM_CHAR data[19+1];
} TM__fug3IAAsDRtODxWPJjHlFg_264 = { 19 | NIM_STRLIT_FLAG, "general parse error" };
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__fug3IAAsDRtODxWPJjHlFg_265 = { 23 | NIM_STRLIT_FLAG, "invalid directive: \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__fug3IAAsDRtODxWPJjHlFg_266 = { 17 | NIM_STRLIT_FLAG, "invalid field: $1" };
static const struct {
  NI cap; NIM_CHAR data[56+1];
} TM__fug3IAAsDRtODxWPJjHlFg_267 = { 56 | NIM_STRLIT_FLAG, "number of footnotes and their references don\'t match: $1" };
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__fug3IAAsDRtODxWPJjHlFg_268 = { 24 | NIM_STRLIT_FLAG, "disabled directive: \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__fug3IAAsDRtODxWPJjHlFg_269 = { 38 | NIM_STRLIT_FLAG, "Cannot prove that \'$1\' is initialized." };
static const struct {
  NI cap; NIM_CHAR data[60+1];
} TM__fug3IAAsDRtODxWPJjHlFg_270 = { 60 | NIM_STRLIT_FLAG, "octal escape sequences do not exist; leading zero is ignored" };
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__fug3IAAsDRtODxWPJjHlFg_271 = { 18 | NIM_STRLIT_FLAG, "\'$1\' is never read" };
static const struct {
  NI cap; NIM_CHAR data[36+1];
} TM__fug3IAAsDRtODxWPJjHlFg_272 = { 36 | NIM_STRLIT_FLAG, "\'$1\' might not have been initialized" };
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__fug3IAAsDRtODxWPJjHlFg_273 = { 30 | NIM_STRLIT_FLAG, "config file \'$1\' is deprecated" };
static const struct {
  NI cap; NIM_CHAR data[64+1];
} TM__fug3IAAsDRtODxWPJjHlFg_274 = { 64 | NIM_STRLIT_FLAG, "\'l\' should not be used as an identifier; may look like \'1\' (one)" };
static const struct {
  NI cap; NIM_CHAR data[43+1];
} TM__fug3IAAsDRtODxWPJjHlFg_275 = { 43 | NIM_STRLIT_FLAG, "unknown magic \'$1\' might crash the compiler" };
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__fug3IAAsDRtODxWPJjHlFg_276 = { 26 | NIM_STRLIT_FLAG, "redefinition of label \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__fug3IAAsDRtODxWPJjHlFg_277 = { 25 | NIM_STRLIT_FLAG, "unknown substitution \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__fug3IAAsDRtODxWPJjHlFg_278 = { 21 | NIM_STRLIT_FLAG, "ambiguous doc link $1" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_279 = { 16 | NIM_STRLIT_FLAG, "broken link \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__fug3IAAsDRtODxWPJjHlFg_280 = { 27 | NIM_STRLIT_FLAG, "language \'$1\' not supported" };
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__fug3IAAsDRtODxWPJjHlFg_281 = { 24 | NIM_STRLIT_FLAG, "field \'$1\' not supported" };
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__fug3IAAsDRtODxWPJjHlFg_282 = { 30 | NIM_STRLIT_FLAG, "importdoc for \'$1\' is not used" };
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_283 = { 13 | NIM_STRLIT_FLAG, "RST style: $1" };
static const struct {
  NI cap; NIM_CHAR data[20+1];
} TM__fug3IAAsDRtODxWPJjHlFg_284 = { 20 | NIM_STRLIT_FLAG, "comment \'$1\' ignored" };
static const struct {
  NI cap; NIM_CHAR data[0+1];
} TM__fug3IAAsDRtODxWPJjHlFg_285 = { 0 | NIM_STRLIT_FLAG, "" };
static const struct {
  NI cap; NIM_CHAR data[62+1];
} TM__fug3IAAsDRtODxWPJjHlFg_286 = { 62 | NIM_STRLIT_FLAG, "use {.base.} for base methods; baseless methods are deprecated" };
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__fug3IAAsDRtODxWPJjHlFg_287 = { 21 | NIM_STRLIT_FLAG, "write to foreign heap" };
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__fug3IAAsDRtODxWPJjHlFg_288 = { 17 | NIM_STRLIT_FLAG, "unsafe code: \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[27+1];
} TM__fug3IAAsDRtODxWPJjHlFg_289 = { 27 | NIM_STRLIT_FLAG, "imported and not used: \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[139+1];
} TM__fug3IAAsDRtODxWPJjHlFg_290 = { 139 | NIM_STRLIT_FLAG, "inherit from a more precise exception type like ValueError, IOError or OSError. If these don\'t suit, inherit from CatchableError or Defect." };
static const struct {
  NI cap; NIM_CHAR data[26+1];
} TM__fug3IAAsDRtODxWPJjHlFg_291 = { 26 | NIM_STRLIT_FLAG, "each identifier is a tuple" };
static const struct {
  NI cap; NIM_CHAR data[104+1];
} TM__fug3IAAsDRtODxWPJjHlFg_292 = { 104 | NIM_STRLIT_FLAG, "setLen can potentially expand the sequence, but the element type \'$1\' doesn\'t have a valid default value" };
static const struct {
  NI cap; NIM_CHAR data[48+1];
} TM__fug3IAAsDRtODxWPJjHlFg_293 = { 48 | NIM_STRLIT_FLAG, "The \'$1\' type doesn\'t have a valid default value" };
static const struct {
  NI cap; NIM_CHAR data[91+1];
} TM__fug3IAAsDRtODxWPJjHlFg_294 = { 91 | NIM_STRLIT_FLAG, "Cannot prove that \'$1\' is initialized. This will become a compile time error in the future." };
static const struct {
  NI cap; NIM_CHAR data[42+1];
} TM__fug3IAAsDRtODxWPJjHlFg_295 = { 42 | NIM_STRLIT_FLAG, "cannot prove that field \'$1\' is accessible" };
static const struct {
  NI cap; NIM_CHAR data[32+1];
} TM__fug3IAAsDRtODxWPJjHlFg_296 = { 32 | NIM_STRLIT_FLAG, "cannot prove index \'$1\' is valid" };
static const struct {
  NI cap; NIM_CHAR data[47+1];
} TM__fug3IAAsDRtODxWPJjHlFg_297 = { 47 | NIM_STRLIT_FLAG, "unreachable else, all cases are already covered" };
static const struct {
  NI cap; NIM_CHAR data[64+1];
} TM__fug3IAAsDRtODxWPJjHlFg_298 = { 64 | NIM_STRLIT_FLAG, "unreachable code after \'return\' statement or \'{.noReturn.}\' proc" };
static const struct {
  NI cap; NIM_CHAR data[17+1];
} TM__fug3IAAsDRtODxWPJjHlFg_299 = { 17 | NIM_STRLIT_FLAG, "not GC-safe: \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[47+1];
} TM__fug3IAAsDRtODxWPJjHlFg_300 = { 47 | NIM_STRLIT_FLAG, "use explicit initialization of \'$1\' for clarity" };
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__fug3IAAsDRtODxWPJjHlFg_301 = { 22 | NIM_STRLIT_FLAG, "\'$1\' uses GC\'ed memory" };
static const struct {
  NI cap; NIM_CHAR data[117+1];
} TM__fug3IAAsDRtODxWPJjHlFg_302 = { 117 | NIM_STRLIT_FLAG, "usage of a type with a destructor in a non destructible context. This will become a compile time error in the future." };
static const struct {
  NI cap; NIM_CHAR data[38+1];
} TM__fug3IAAsDRtODxWPJjHlFg_303 = { 38 | NIM_STRLIT_FLAG, "Special variable \'result\' is shadowed." };
static const struct {
  NI cap; NIM_CHAR data[46+1];
} TM__fug3IAAsDRtODxWPJjHlFg_304 = { 46 | NIM_STRLIT_FLAG, "Number of spaces around \'$#\' is not consistent" };
static const struct {
  NI cap; NIM_CHAR data[64+1];
} TM__fug3IAAsDRtODxWPJjHlFg_305 = { 64 | NIM_STRLIT_FLAG, "Potential object case transition, instantiate new object instead" };
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__fug3IAAsDRtODxWPJjHlFg_306 = { 25 | NIM_STRLIT_FLAG, "observable stores to \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[22+1];
} TM__fug3IAAsDRtODxWPJjHlFg_307 = { 22 | NIM_STRLIT_FLAG, "used \'result\' variable" };
static const struct {
  NI cap; NIM_CHAR data[15+1];
} TM__fug3IAAsDRtODxWPJjHlFg_308 = { 15 | NIM_STRLIT_FLAG, "cannot open: $1" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_309 = { 16 | NIM_STRLIT_FLAG, "file changed: $1" };
static const struct {
  NI cap; NIM_CHAR data[141+1];
} TM__fug3IAAsDRtODxWPJjHlFg_310 = { 141 | NIM_STRLIT_FLAG, "unsafe conversion to \'cstring\' from \'$1\'; Use a `cast` operation like `cast[cstring](x)`; this will become a compile time error in the future" };
static const struct {
  NI cap; NIM_CHAR data[91+1];
} TM__fug3IAAsDRtODxWPJjHlFg_311 = { 91 | NIM_STRLIT_FLAG, "template \'$1\' is implicitly redefined; this is deprecated, add an explicit .redefine pragma" };
static const struct {
  NI cap; NIM_CHAR data[93+1];
} TM__fug3IAAsDRtODxWPJjHlFg_312 = { 93 | NIM_STRLIT_FLAG, "Using an unnamed break in a block is deprecated; Use a named block with a named break instead" };
static const struct {
  NI cap; NIM_CHAR data[119+1];
} TM__fug3IAAsDRtODxWPJjHlFg_313 = { 119 | NIM_STRLIT_FLAG, "statement list expression assumed to be anonymous proc; this is deprecated, use `do (): ...` or `proc () = ...` instead" };
static const struct {
  NI cap; NIM_CHAR data[25+1];
} TM__fug3IAAsDRtODxWPJjHlFg_314 = { 25 | NIM_STRLIT_FLAG, "$1 needs the \'std\' prefix" };
static const struct {
  NI cap; NIM_CHAR data[65+1];
} TM__fug3IAAsDRtODxWPJjHlFg_315 = { 65 | NIM_STRLIT_FLAG, "global variable \'$1\' initialization requires a temporary variable" };
static const struct {
  NI cap; NIM_CHAR data[28+1];
} TM__fug3IAAsDRtODxWPJjHlFg_316 = { 28 | NIM_STRLIT_FLAG, "implicit range conversion $1" };
static const struct {
  NI cap; NIM_CHAR data[24+1];
} TM__fug3IAAsDRtODxWPJjHlFg_317 = { 24 | NIM_STRLIT_FLAG, "operation successful: $#" };
static const struct {
  NI cap; NIM_CHAR data[62+1];
} TM__fug3IAAsDRtODxWPJjHlFg_318 = { 62 | NIM_STRLIT_FLAG, "$build\012$loc lines; ${sec}s; $mem; proj: $project; out: $output" };
static const struct {
  NI cap; NIM_CHAR data[6+1];
} TM__fug3IAAsDRtODxWPJjHlFg_319 = { 6 | NIM_STRLIT_FLAG, "CC: $1" };
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__fug3IAAsDRtODxWPJjHlFg_320 = { 29 | NIM_STRLIT_FLAG, "\'$1\' is declared but not used" };
static const struct {
  NI cap; NIM_CHAR data[39+1];
} TM__fug3IAAsDRtODxWPJjHlFg_321 = { 39 | NIM_STRLIT_FLAG, "conversion to base object is not needed" };
static const struct {
  NI cap; NIM_CHAR data[41+1];
} TM__fug3IAAsDRtODxWPJjHlFg_322 = { 41 | NIM_STRLIT_FLAG, "conversion from $1 to itself is pointless" };
static const struct {
  NI cap; NIM_CHAR data[35+1];
} TM__fug3IAAsDRtODxWPJjHlFg_323 = { 35 | NIM_STRLIT_FLAG, "expression evaluates always to \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[13+1];
} TM__fug3IAAsDRtODxWPJjHlFg_324 = { 13 | NIM_STRLIT_FLAG, "quit() called" };
static const struct {
  NI cap; NIM_CHAR data[23+1];
} TM__fug3IAAsDRtODxWPJjHlFg_325 = { 23 | NIM_STRLIT_FLAG, "generated code listing:" };
static const struct {
  NI cap; NIM_CHAR data[14+1];
} TM__fug3IAAsDRtODxWPJjHlFg_326 = { 14 | NIM_STRLIT_FLAG, "end of listing" };
static const struct {
  NI cap; NIM_CHAR data[21+1];
} TM__fug3IAAsDRtODxWPJjHlFg_327 = { 21 | NIM_STRLIT_FLAG, "used config file \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[16+1];
} TM__fug3IAAsDRtODxWPJjHlFg_328 = { 16 | NIM_STRLIT_FLAG, "added path: \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__fug3IAAsDRtODxWPJjHlFg_329 = { 30 | NIM_STRLIT_FLAG, "condition is always true: \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[31+1];
} TM__fug3IAAsDRtODxWPJjHlFg_330 = { 31 | NIM_STRLIT_FLAG, "condition is always false: \'$1\'" };
static const struct {
  NI cap; NIM_CHAR data[29+1];
} TM__fug3IAAsDRtODxWPJjHlFg_331 = { 29 | NIM_STRLIT_FLAG, "global variable declared here" };
static const struct {
  NI cap; NIM_CHAR data[18+1];
} TM__fug3IAAsDRtODxWPJjHlFg_332 = { 18 | NIM_STRLIT_FLAG, "expanded macro: $1" };
static const struct {
  NI cap; NIM_CHAR data[84+1];
} TM__fug3IAAsDRtODxWPJjHlFg_333 = { 84 | NIM_STRLIT_FLAG, "$1 is a forward declaration without explicit .raises, assuming it can raise anything" };
static const struct {
  NI cap; NIM_CHAR data[30+1];
} TM__fug3IAAsDRtODxWPJjHlFg_334 = { 30 | NIM_STRLIT_FLAG, "https://nim-lang.github.io/Nim" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_335 = {30, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_334};
static const struct {
  NI cap; NIM_CHAR data[1+1];
} TM__fug3IAAsDRtODxWPJjHlFg_336 = { 1 | NIM_STRLIT_FLAG, "/" };
static const NimStringV2 TM__fug3IAAsDRtODxWPJjHlFg_337 = {1, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_336};
N_LIB_PRIVATE TNimTypeV2 NTIv2__ufikPAIN9baqODve3UZ6YVA_;
N_LIB_PRIVATE TNimTypeV2 NTIv2__CLyaY3uTAyl9bLjvrz9aqX9bA_;
N_LIB_PRIVATE NIM_CONST tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA unknownLineInfo__lineinfos_u364 = {((NU16)0), ((NI16)-1), ((NI32)-1)}
;
N_LIB_PRIVATE NIM_CONST tyArray__jQ6Zibb0SzsKfL1Qwwi9bag NotesVerbosity__lineinfos_u228 = {{
0xff, 0xff, 0xff, 0xcf, 0xfd, 0xd7, 0xfd, 0xb7,
0x07, 0x7f, 0xe0, 0x00, 0x2e}
,
{
0xff, 0xff, 0xff, 0xcf, 0xfd, 0xd7, 0xfd, 0xb7,
0xe7, 0xff, 0xe8, 0x07, 0x2e}
,
{
0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xfd, 0xb7,
0xef, 0xff, 0xfe, 0xbf, 0x6f}
,
{
0xff, 0xff, 0xff, 0xff, 0xff, 0xd7, 0xfd, 0xb7,
0xef, 0xff, 0xff, 0xff, 0xff}
}
;
N_LIB_PRIVATE NIM_CONST tyArray__pKMShAYxu8WJVt39cC69bQ9aQ MsgKindToStr__lineinfos_u137 = {{13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_253},
{15, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_254},
{18, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_255},
{17, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_256},
{16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_257},
{13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_258},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{29, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_260},
{43, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_261},
{19, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_262},
{23, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_263},
{19, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_264},
{23, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_265},
{17, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_266},
{56, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_267},
{24, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_268},
{38, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_269},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_257},
{60, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_270},
{18, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_271},
{36, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_272},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{30, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_273},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{64, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_274},
{43, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_275},
{26, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_276},
{25, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_277},
{21, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_278},
{16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_279},
{27, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_280},
{24, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_281},
{30, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_282},
{13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_283},
{20, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_284},
{0, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_285},
{62, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_286},
{21, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_287},
{17, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_288},
{27, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_289},
{139, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_290},
{26, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_291},
{104, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_292},
{48, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_293},
{91, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_294},
{42, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_295},
{32, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_296},
{47, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_297},
{64, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_298},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{17, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_299},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{47, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_300},
{22, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_301},
{117, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_302},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{38, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_303},
{46, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_304},
{64, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_305},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{25, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_306},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{22, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_307},
{15, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_308},
{16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_309},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{141, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_310},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{91, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_311},
{93, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_312},
{119, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_313},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{25, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_314},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{65, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_315},
{28, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_316},
{28, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_316},
{24, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_317},
{62, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_318},
{6, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_319},
{29, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_320},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{39, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_321},
{41, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_322},
{35, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_323},
{13, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_324},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{23, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_325},
{14, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_326},
{21, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_327},
{16, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_328},
{30, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_329},
{31, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_330},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{29, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_331},
{18, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_332},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{84, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_333},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259},
{2, (NimStrPayload*)&TM__fug3IAAsDRtODxWPJjHlFg_259}}
;
extern NIM_BOOL nimInErrorMode__system_u4143;
static NIM_CONST NU32 TM__fug3IAAsDRtODxWPJjHlFg_338[5] = {3701606400, 1285336064, 561960192, 1871340544, 4171512832};
N_LIB_PRIVATE TNimTypeV2 NTIv2__ufikPAIN9baqODve3UZ6YVA_ = {.destructor = (void*)rttiDestroy__lineinfos_u2356, .size = sizeof(tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA), .align = (NI16) NIM_ALIGNOF(tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA), .depth = 4, .display = TM__fug3IAAsDRtODxWPJjHlFg_338, .traceImpl = (void*)eqtrace___lineinfos_u317, .flags = 0};
static NIM_CONST NU32 TM__fug3IAAsDRtODxWPJjHlFg_339[5] = {3701606400, 1285336064, 561960192, 1871340544, 3164234496};
N_LIB_PRIVATE TNimTypeV2 NTIv2__CLyaY3uTAyl9bLjvrz9aqX9bA_ = {.destructor = (void*)rttiDestroy__lineinfos_u2358, .size = sizeof(tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA), .align = (NI16) NIM_ALIGNOF(tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA), .depth = 4, .display = TM__fug3IAAsDRtODxWPJjHlFg_339, .traceImpl = (void*)eqtrace___msgs_u500, .flags = 0};
static N_INLINE(void, nimSetMem__system_u2172)(void* a_p0, int v_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memset(a_p0, v_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, nimZeroMem)(void* p_p0, NI size_p1) {
	nimSetMem__system_u2172(p_p0, ((int)0), size_p1);
}
N_LIB_PRIVATE N_NIMCALL(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA, eqdup___lineinfos_u2037)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA src_p0) {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA result;
	nimZeroMem((void*)(&result), sizeof(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA));
	result.line = src_p0.line;
	result.col = src_p0.col;
	result.fileIndex = src_p0.fileIndex;
	return result;
}
static N_INLINE(NIM_BOOL*, nimErrorFlag)(void) {
	NIM_BOOL* result;
	result = (&nimInErrorMode__system_u4143);
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, initMsgConfig__lineinfos_u392)(tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw* Result) {
	tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA colontmpD_;
	tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	nimZeroMem((void*)Result, sizeof(tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw));
	nimZeroMem((void*)Result, sizeof(tyObject_MsgConfig__E1VAUnnaNIOngCdEgTI2Dw));
	(*Result).msgContext.len = 0; (*Result).msgContext.p = (tySequence__E0kio2ZnplNTuln9bsnljSA_Content*) newSeqPayload(0, sizeof(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ), NIM_ALIGNOF(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ));
	colontmpD_ = eqdup___lineinfos_u2037(unknownLineInfo__lineinfos_u364);
	(*Result).lastError = colontmpD_;
	nimZeroMem((void*)(&T1_), sizeof(tyObject_Table__PBlYIBD9bHKBu5FQE5lPn7A));
	T1_ = initTable__lineinfos_u410(((NI)32));
	if (NIM_UNLIKELY(*nimErr_)) {eqdestroy___lineinfos_u548(T1_); goto BeforeRet_;}
	(*Result).filenameToIndexTbl = T1_;
	(*Result).fileInfos.len = 0; (*Result).fileInfos.p = (tySequence__hTEiKNj3evQAjIXUI21elA_Content*) newSeqPayload(0, sizeof(tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw), NIM_ALIGNOF(tyObject_TFileInfo__xPdjmgevOVG8T0Aq8BK7jw));
	(*Result).errorOutputs = 3;
	X5BX5Deq___lineinfos_u646((&(*Result).filenameToIndexTbl), TM__fug3IAAsDRtODxWPJjHlFg_3, ((NI32)-1));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, dollar___lineinfos_u134)(tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA e_p0) {
	NimStringV2 result;
	switch (e_p0) {
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)0):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_5;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)1):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_7;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)2):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_9;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)3):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_11;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)4):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_13;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)5):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_15;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)6):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_17;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)7):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_19;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)8):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_21;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)9):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_23;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)10):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_25;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)11):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_27;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)12):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_29;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)13):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_31;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)14):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_33;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)15):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_35;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)16):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_37;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)17):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_39;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)18):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_41;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)19):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_43;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)20):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_45;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)21):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_47;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)22):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_49;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)23):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_51;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)24):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_53;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)25):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_55;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)26):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_57;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)27):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_59;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)28):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_61;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)29):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_63;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)30):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_65;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)31):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_67;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)32):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_69;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)33):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_71;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)34):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_73;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)35):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_75;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)36):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_77;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)37):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_79;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)38):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_81;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)39):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_83;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)40):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_85;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)41):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_87;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)42):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_89;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)43):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_91;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)44):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_93;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)45):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_95;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)46):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_97;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)47):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_99;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)48):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_101;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)49):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_103;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)50):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_105;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)51):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_107;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)52):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_109;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)53):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_111;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)54):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_113;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)55):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_115;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)56):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_117;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)57):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_119;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)58):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_121;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)59):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_123;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)60):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_125;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)61):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_127;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)62):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_129;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)63):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_131;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)64):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_133;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)65):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_135;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)66):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_137;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)67):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_139;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)68):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_141;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)69):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_143;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)70):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_145;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)71):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_147;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)72):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_149;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)73):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_151;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)74):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_153;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)75):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_155;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)76):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_157;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)77):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_159;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)78):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_161;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)79):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_163;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)80):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_165;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)81):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_167;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)82):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_169;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)83):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_171;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)84):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_173;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)85):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_175;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)86):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_177;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)87):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_179;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)88):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_181;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)89):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_183;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)90):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_185;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)91):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_187;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)92):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_189;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)93):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_191;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)94):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_193;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)95):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_195;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)96):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_197;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)97):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_199;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)98):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_201;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)99):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_203;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)100):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_205;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)101):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_207;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)102):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_209;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)103):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_211;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)104):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_213;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)105):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_215;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)106):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_217;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)107):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_219;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)108):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_221;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)109):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_223;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)110):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_225;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)111):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_227;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)112):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_229;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)113):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_231;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)114):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_233;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)115):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_235;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)116):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_237;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)117):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_239;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)118):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_240;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)119):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_242;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)120):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_244;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)121):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_246;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)122):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_248;
	}
	break;
	case ((tyEnum_TMsgKind__Ug4VJQkHi8g218Fa9bQrePA)123):
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_250;
	}
	break;
	default:
	{
		result = TM__fug3IAAsDRtODxWPJjHlFg_252;
	}
	break;
	}
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqcopy___lineinfos_u1910)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ* dest_p0, tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ src_p1) {
	(*dest_p0).Field0.line = src_p1.Field0.line;
	(*dest_p0).Field0.col = src_p1.Field0.col;
	(*dest_p0).Field0.fileIndex = src_p1.Field0.fileIndex;
	eqcopy___system_u2694((&(*dest_p0).Field1), src_p1.Field1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u1907)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ dest_p0) {
	eqdestroy___system_u2691(dest_p0.Field1);
}
static N_INLINE(void, nimCopyMem)(void* dest_p0, void* source_p1, NI size_p2) {
	void* T1_;
	T1_ = (void*)0;
	T1_ = memcpy(dest_p0, source_p1, ((size_t) (size_p2)));
}
static N_INLINE(void, copyMem__system_u1742)(void* dest_p0, void* source_p1, NI size_p2) {
	nimCopyMem(dest_p0, source_p1, size_p2);
}
static N_INLINE(void, appendString)(NimStringV2* dest_p0, NimStringV2 src_p1) {
	{
		if (!(((NI)0) < src_p1.len)) goto LA3_;
		copyMem__system_u1742(((void*) ((&(*(*dest_p0).p).data[(*dest_p0).len]))), ((void*) ((&(*src_p1.p).data[((NI)0)]))), (src_p1.len));
		(*dest_p0).len += src_p1.len;
		(*(*dest_p0).p).data[(*dest_p0).len] = 0;
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(NimStringV2, createDocLink__lineinfos_u6)(NimStringV2 urlSuffix_p0) {
	NimStringV2 result;
	result = TM__fug3IAAsDRtODxWPJjHlFg_335;
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = (((NI)0) < urlSuffix_p0.len);
		if (!(T3_)) goto LA4_;
		T3_ = ((NU8)(urlSuffix_p0.p->data[((NI)0)]) == (NU8)(47));
LA4_: ;
		if (!T3_) goto LA5_;
		prepareAdd((&result), urlSuffix_p0.len + 0);
appendString((&result), urlSuffix_p0);
	}
	goto LA1_;
LA5_: ;
	{
		NimStringV2 colontmpD_;
		NimStringV2 T8_;
		colontmpD_.len = 0; colontmpD_.p = NIM_NIL;
		T8_.len = 0; T8_.p = NIM_NIL;
		T8_ = rawNewString(urlSuffix_p0.len + 1);
appendString((&T8_), TM__fug3IAAsDRtODxWPJjHlFg_337);
appendString((&T8_), urlSuffix_p0);
		colontmpD_ = T8_;
		prepareAdd((&result), colontmpD_.len + 0);
appendString((&result), colontmpD_);
		eqdestroy___system_u2691(colontmpD_);
	}
LA1_: ;
	return result;
}
static N_INLINE(NI, minuspercent___system_u805)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) - (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(NIM_BOOL, nimDecRefIsLastCyclicDyn)(void* p_p0) {
	NIM_BOOL result;
	result = NIM_FALSE;
	{
		tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A* cell_1;
		NI T5_;
		if (!!((p_p0 == NIM_NIL))) goto LA3_;
		T5_ = (NI)0;
		T5_ = minuspercent___system_u805(((NI) (ptrdiff_t) (p_p0)), ((NI)16));
		cell_1 = ((tyObject_RefHeader__GDnGTjNyvwISJbkIvAst3A*) (T5_));
		{
			if (!((NI)((*cell_1).rc & ((NI)-16)) == ((NI)0))) goto LA8_;
			result = NIM_TRUE;
		}
		goto LA6_;
LA8_: ;
		{
			(*cell_1).rc = minuspercent___system_u805((*cell_1).rc, ((NI)16));
		}
LA6_: ;
		rememberCycle__system_u3497(result, cell_1, (*((TNimTypeV2**) (p_p0))));
	}
LA3_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u305)(tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn((*dest_p0).Sup.Sup.Sup.up);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose((*dest_p0).Sup.Sup.Sup.up);
	}
LA4_: ;
	eqdestroy___system_u3699((*dest_p0).Sup.Sup.Sup.trace);
	eqdestroy___system_u2691((*dest_p0).Sup.Sup.Sup.message);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastCyclicDyn((*dest_p0).Sup.Sup.Sup.parent);
		if (!T8_) goto LA9_;
		nimDestroyAndDispose((*dest_p0).Sup.Sup.Sup.parent);
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__lineinfos_u2356)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___lineinfos_u305((&(*((tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
static N_INLINE(NI, pluspercent___system_u785)(NI x_p0, NI y_p1) {
	NI result;
	result = ((NI) ((NU)((NU64)(((NU) (x_p0))) + (NU64)(((NU) (y_p1))))));
	return result;
}
static N_INLINE(void, add__system_u3018)(tyObject_CellSeq__gW9aeWLFbrNaeUKXqxYBXhg* s_p0, void** c_p1, TNimTypeV2* t_p2) {
	void** colontmp_;
	TNimTypeV2* colontmp__2;
	{
		if (!((*s_p0).cap <= (*s_p0).len)) goto LA3_;
		resize__system_u3026(s_p0);
	}
LA3_: ;
	colontmp_ = c_p1;
	colontmp__2 = t_p2;
	(*s_p0).d[(*s_p0).len].Field0 = colontmp_;
	(*s_p0).d[(*s_p0).len].Field1 = colontmp__2;
	(*s_p0).len = pluspercent___system_u785((*s_p0).len, ((NI)1));
}
static N_INLINE(void, nimTraceRefDyn)(void* q_p0, void* env_p1) {
	void** p_1;
	p_1 = ((void**) (q_p0));
	{
		tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w* j_1;
		if (!!(((*p_1) == NIM_NIL))) goto LA3_;
		j_1 = ((tyObject_GcEnv__HccVszwojlCZRN46BE9cG8w*) (env_p1));
		add__system_u3018((&(*j_1).traceStack), p_1, (*((TNimTypeV2**) ((*p_1)))));
	}
LA3_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___lineinfos_u317)(tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).Sup.Sup.Sup.parent, env_p1);
	nimTraceRefDyn(&(*dest_p0).Sup.Sup.Sup.up, env_p1);
}
N_LIB_PRIVATE N_NOINLINE(void, raiseRecoverableError__lineinfos_u299)(NimStringV2 msg_p0) {
	NimStringV2 colontmpD_;
	tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA* T1_;
{	T1_ = NIM_NIL;
	T1_ = (tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA*) nimNewObj(sizeof(tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA), NIM_ALIGNOF(tyObject_ERecoverableError__ufikPAIN9baqODve3UZ6YVA));
	(*T1_).Sup.Sup.Sup.Sup.m_type = (&NTIv2__ufikPAIN9baqODve3UZ6YVA_);
	(*T1_).Sup.Sup.Sup.name = "ERecoverableError";
	colontmpD_ = eqdup___system_u2697(msg_p0);
	(*T1_).Sup.Sup.Sup.message = colontmpD_;
	(*T1_).Sup.Sup.Sup.parent = ((Exception*) NIM_NIL);
	raiseExceptionEx((Exception*)T1_, "ERecoverableError", "raiseRecoverableError", "lineinfos.nim", 331);
goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(NI, hash__lineinfos_u261)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA i_p0) {
	NI result;
	tyTuple__47w2DboNEPf69aPgubZdd7Q T1_;
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	result = (NI)0;
	T1_.Field0 = ((NI) (i_p0.line));
	T1_.Field1 = ((NI) (i_p0.col));
	T1_.Field2 = ((NI) (i_p0.fileIndex));
	result = hash__lineinfos_u264(T1_);
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
	return result;
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lineinfos_u1904)(tyTuple__ji9a7IXpM9cONa0mh0VGCVrQ* dest_p0) {
	(*dest_p0).Field0.line = 0;
	(*dest_p0).Field0.col = 0;
	(*dest_p0).Field0.fileIndex = 0;
	(*dest_p0).Field1.len = 0; (*dest_p0).Field1.p = NIM_NIL;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___msgs_u488)(tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA* dest_p0) {
	{
		NIM_BOOL T3_;
		T3_ = (NIM_BOOL)0;
		T3_ = nimDecRefIsLastCyclicDyn((*dest_p0).Sup.Sup.Sup.up);
		if (!T3_) goto LA4_;
		nimDestroyAndDispose((*dest_p0).Sup.Sup.Sup.up);
	}
LA4_: ;
	eqdestroy___system_u3699((*dest_p0).Sup.Sup.Sup.trace);
	eqdestroy___system_u2691((*dest_p0).Sup.Sup.Sup.message);
	{
		NIM_BOOL T8_;
		T8_ = (NIM_BOOL)0;
		T8_ = nimDecRefIsLastCyclicDyn((*dest_p0).Sup.Sup.Sup.parent);
		if (!T8_) goto LA9_;
		nimDestroyAndDispose((*dest_p0).Sup.Sup.Sup.parent);
	}
LA9_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, rttiDestroy__lineinfos_u2358)(void* dest_p0) {
NIM_BOOL* nimErr_;
{nimErr_ = nimErrorFlag();
	eqdestroy___msgs_u488((&(*((tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA*) (dest_p0)))));
	if (NIM_UNLIKELY(*nimErr_)) goto BeforeRet_;
	}BeforeRet_: ;
}
N_LIB_PRIVATE N_NIMCALL(void, eqtrace___msgs_u500)(tyObject_ESuggestDone__CLyaY3uTAyl9bLjvrz9aqX9bA* dest_p0, void* env_p1) {
	nimTraceRefDyn(&(*dest_p0).Sup.Sup.Sup.parent, env_p1);
	nimTraceRefDyn(&(*dest_p0).Sup.Sup.Sup.up, env_p1);
}
N_LIB_PRIVATE N_NIMCALL(void, eqwasMoved___lineinfos_u2028)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA* dest_p0) {
	(*dest_p0).line = 0;
	(*dest_p0).col = 0;
	(*dest_p0).fileIndex = 0;
}
N_LIB_PRIVATE N_NIMCALL(void, eqdestroy___lineinfos_u2031)(tyObject_TLineInfo__cGj50BJ9bj3Zx09a9bMvKs8HA dest_p0) {
}
